@@ -84,7 +84,7 @@ class Trilio:
                     "collections" : []
                 }
             }
-            if self.validate_address(private_key, public_key) == False:
+            if self.validate_wallet(private_key, public_key) == False:
                 self.addresses.append(cred_keys)
                 return cred_keys
             else:
